@@ -5,10 +5,11 @@
 # Copyright (C) 2021 The lesscode Team
 import logging
 import traceback
-import prettytable
+from functools import reduce
+
 from nebula3.data.ResultSet import ResultSet
 from tornado.options import options
-from nebula3.data.DataObject import Value, ValueWrapper
+from nebula3.data.DataObject import Value, ValueWrapper, Relationship, PathWrapper
 from nebula3.mclient import MetaCache, HostAddr
 from nebula3.sclient.GraphStorageClient import GraphStorageClient
 
@@ -109,6 +110,23 @@ cast_as = {
 }
 
 
+def list_dict_duplicate_removal(data_list):
+    run_function = lambda x, y: x if y in x else x + [y]
+    return reduce(run_function, [[], ] + data_list)
+
+
+def merge_nebula_value(data_list: list) -> dict:
+    nodes = []
+    relationships = []
+
+    for data in data_list:
+        nodes.extend(list(data.values())[0]["nodes"])
+        relationships.extend(list(data.values())[0]["relationships"])
+    result_dict = {"nodes": list_dict_duplicate_removal(nodes),
+                   "relationships": list_dict_duplicate_removal(relationships)}
+    return result_dict
+
+
 def customized_cast_with_dict(val: ValueWrapper):
     _type = val._value.getType()
     method = cast_as.get(_type)
@@ -130,6 +148,23 @@ def customized_cast_with_dict(val: ValueWrapper):
             for v in value:
                 new_value.append(customized_cast_with_dict(v))
             value = tuple(new_value)
+        elif isinstance(value, Relationship):
+            value = value.properties()
+        elif isinstance(value, PathWrapper):
+            nodes = []
+            relationships = []
+            for node in value.nodes():
+                vid = str(node.get_id())
+                for tag in node.tags():
+                    point = {"_vid": vid, "_tag": tag}
+                    point.update({k: customized_cast_with_dict(v) for k, v in node.properties(tag).items()})
+                    nodes.append(point)
+            for rel in value.relationships():
+                relationship = {"_name": rel.edge_name(), "_start": str(rel.start_vertex_id()),
+                                "_end": str(rel.end_vertex_id())}
+                relationship.update({k: customized_cast_with_dict(v) for k, v in rel.properties().items()})
+                relationships.append(relationship)
+            value = {"nodes": nodes, "relationships": relationships}
         return value
     raise KeyError("No such key: {}".format(_type))
 
