@@ -181,10 +181,15 @@ def list2table(title: str, head, data: list, column_keys: dict = None, index_dic
     return result
 
 
+def convert(value, func):
+    return func(value)
+
+
 def list2table_with_page(title: str, head, data: list, column_keys: dict = None, index_dict: dict = None,
-                         page_num: int = 1, page_size: int = 10, total: int = 0):
+                         page_num: int = 1, page_size: int = 10, total: int = 0, column_covert: dict = None):
     """
     list数据转换成表格
+    :param column_covert: {"id":str}
     :param total: 数据总数
     :param page_size: 每页数量
     :param page_num: 页码
@@ -215,7 +220,11 @@ def list2table_with_page(title: str, head, data: list, column_keys: dict = None,
             data_item = {
             }
             for key, value in column_keys.items():
-                data_item[key] = get_value_from_dict(item, value)
+                new_value = get_value_from_dict(item, value)
+                if column_covert:
+                    if key in column_covert:
+                        new_value = convert(new_value, column_covert.get(key))
+                data_item[key] = new_value
             result["dataSource"].append(data_item)
     else:
         result["dataSource"] = data
